@@ -125,11 +125,15 @@ class ANN:
         # ISO 8601 timestamp
         create = datetime.datetime.now(datetime.timezone.utc).strftime("%Y-%m-%dT%H:%M:%SZ")
 
-        # Set build metadata
-        self.config["build"] = {
-            "create": create,
-            "python": platform.python_version(),
-            "settings": settings,
-            "system": f"{platform.system()} ({platform.machine()})",
-            "txtai": __version__,
-        }
+        # Set build metadata if this is not an update
+        if settings:
+            self.config["build"] = {
+                "create": create,
+                "python": platform.python_version(),
+                "settings": settings,
+                "system": f"{platform.system()} ({platform.machine()})",
+                "txtai": __version__,
+            }
+
+        # Set last update date
+        self.config["update"] = create
