@@ -2,9 +2,9 @@
 Factory module
 """
 
-from .annoy import Annoy
-from .faiss import Faiss, FAISS
-from .hnsw import HNSW
+from .annoy import Annoy, ANNOY
+from .faiss import Faiss
+from .hnsw import HNSW, HNSWLIB
 
 
 class ANNFactory:
@@ -26,22 +26,20 @@ class ANNFactory:
 
         # ANN model
         model = None
-        backend = config.get("backend")
-
-        # Default backend if not provided, based on available libraries
-        if not backend:
-            backend = "faiss" if FAISS else "hnsw"
+        backend = config.get("backend", "faiss")
 
         # Create ANN instance
         if backend == "annoy":
+            if not ANNOY:
+                raise ImportError('annoy library is not available - install "similarity" extra to enable')
+
             model = Annoy(config)
         elif backend == "hnsw":
+            if not HNSWLIB:
+                raise ImportError('hnswlib library is not available - install "similarity" extra to enable')
+
             model = HNSW(config)
         else:
-            # Raise error if trying to create a Faiss index without Faiss installed
-            if not FAISS:
-                raise ImportError("Faiss library is not installed")
-
             model = Faiss(config)
 
         # Store config back
