@@ -3,6 +3,6 @@ SQL imports
 """
 
 from .aggregate import Aggregate
-from .base import SQL, SQLException
+from .base import SQL, SQLError
 from .expression import Expression
 from .token import Token
