@@ -94,7 +94,10 @@ class SQL:
             True if this is a valid SQL query, False otherwise
         """
 
-        query = query.lower().strip(";")
+        # Reduce query to a lower-cased single line stripped of leading/trailing whitespace
+        query = query.lower().strip(";").replace("\n", " ").replace("\t", " ").strip()
+
+        # Detect if this is a valid txtai SQL statement
         return query.startswith("select ") and (" from txtai " in query or query.endswith(" from txtai"))
 
     def tokenize(self, query):
@@ -162,7 +165,7 @@ class SQL:
         return clause
 
 
-class SQLException(Exception):
+class SQLError(Exception):
     """
-    Raised for exceptions generated by user SQL queries
+    Raised for errors generated by user SQL queries
     """
