@@ -7,7 +7,6 @@ import pickle
 import os
 import shutil
 import tempfile
-import types
 
 import numpy as np
 
@@ -269,7 +268,7 @@ class Embeddings:
 
         return self.ann.count() if self.ann else 0
 
-    def search(self, query, limit=3):
+    def search(self, query, limit=None):
         """
         Finds documents most similar to the input queries. This method will run either an approximate
         nearest neighbor (ann) search or an approximate nearest neighbor + database search depending
@@ -283,10 +282,10 @@ class Embeddings:
             list of (id, score) for ann search, list of dict for an ann+database search
         """
 
-        results = self.batchsearch([query], limit)
+        results = self.batchsearch([query], limit if limit else 3)
         return results[0] if results else results
 
-    def batchsearch(self, queries, limit=3):
+    def batchsearch(self, queries, limit=None):
         """
         Finds documents most similar to the input queries. This method will run either an approximate
         nearest neighbor (ann) search or an approximate nearest neighbor + database search depending
@@ -300,7 +299,7 @@ class Embeddings:
             list of (id, score) per query for ann search, list of dict per query for an ann+database search
         """
 
-        return Search(self)(queries, limit)
+        return Search(self)(queries, limit if limit else 3)
 
     def similarity(self, query, data):
         """
@@ -471,13 +470,8 @@ class Embeddings:
         # Remove ids array if present
         config.pop("ids", None)
 
-        # Format functions
-        for key in config:
-            if isinstance(config[key], types.FunctionType):
-                config[key] = "<function>"
-
         # Print configuration
-        print(json.dumps(config, sort_keys=True, indent=2))
+        print(json.dumps(config, sort_keys=True, default=str, indent=2))
 
     def configure(self, config):
         """
