@@ -21,7 +21,7 @@ class Vectors:
             self.tokenize = config.get("tokenize")
 
             # pylint: disable=E1111
-            self.model = self.load(config["path"])
+            self.model = self.load(config.get("path"))
 
     def load(self, path):
         """
@@ -42,7 +42,7 @@ class Vectors:
         number of dimensions and temporary file with embeddings.
 
         Args:
-            documents: list of (id, text|tokens, tags)
+            documents: list of (id, data, tags)
 
         Returns:
             (ids, dimensions, stream)
@@ -55,7 +55,7 @@ class Vectors:
         Transforms document into an embeddings vector.
 
         Args:
-            document: (id, text|tokens, tags)
+            document: (id, data, tags)
 
         Returns:
             embeddings vector
