@@ -12,12 +12,13 @@ class WorkflowFactory:
     """
 
     @staticmethod
-    def create(config):
+    def create(config, name):
         """
         Creates a new Workflow instance.
 
         Args:
             config: Workflow configuration
+            name: Workflow name
 
         Returns:
             Workflow
@@ -32,4 +33,4 @@ class WorkflowFactory:
         config["tasks"] = tasks
 
         # Create workflow
-        return Workflow(**config)
+        return Workflow(**config, name=name)
