@@ -3,9 +3,12 @@ Task imports
 """
 
 from .base import Task
+from .console import ConsoleTask
+from .export import ExportTask
 from .factory import TaskFactory
 from .file import FileTask
 from .image import ImageTask
+from .retrieve import RetrieveTask
 from .service import ServiceTask
 from .storage import StorageTask
 from .url import UrlTask
